/*  Project owlmovie
    
    Copyright  1995 Greg Arakelian. All Rights Reserved.

    SUBSYSTEM:    owlmovie.exe Application
    FILE:         maincli.cpp
    AUTHOR:       Greg Arakelian


    OVERVIEW
    ========
    Source file for implementation of TMainDlgClient (TDialog).      
*/


#include <owl\owlpch.h>
#pragma hdrstop

#include "mainapp.h"
#include "maincli.h"


//{{TMainDlgClient Implementation}}


//////////////////////////////////////////////////////////
// TMainDlgClient
// ==========
// Construction/Destruction handling.
TMainDlgClient::TMainDlgClient (TWindow *parent, TResId resId, TModule *module)
    : TDialog(parent, resId, module)
{

  //
  // Create sprites and movie control
  //
  SetBkgndColor(GetSysColor(COLOR_BTNFACE));
  string buildDate = "(Build ";
  buildDate.append(__DATE__);
  buildDate.append(")\n");
  TSize frameSize(256,200);
  TMovieSprite *movieSprite = new TMovieSprite(frameSize);
  movieSprite->Append(new TFlicSprite(GetModule(),"WINSTART",1),true);
  movieSprite->Append(new TFlicSprite(GetModule(),"WINWAVE"));
  movieSprite->RollText(IDS_PAUSE,MSCF_WHITESPACE);
  movieSprite->RollText(IDS_PRODUCTNAME,MSCF_HEADING);
  buildDate += GetApplication()->LoadString(IDS_COPYRIGHT);
  movieSprite->RollText(buildDate.c_str(),MSCF_WHITESPACE);
  movieSprite->RollText(IDS_FEATURES,MSCF_HEADING);
  movieSprite->RollText(IDS_FEATURELIST,MSCF_JUSTIFY_LEFT|MSCF_WHITESPACE);
  movieSprite->RollText(IDS_PLEASEREGISTER,MSCF_HEADING);
  movieSprite->RollText(IDS_HOWTOREGISTER,MSCF_WHITESPACE|MSCF_JUSTIFY_LEFT);
  movieSprite->RollDib(GetModule(),IDB_PORTRAIT);
  movieSprite->RollText(IDS_ARAKELIAN,MSCF_HEADING);
  movieSprite->RollText(IDS_DESIGNER,MSCF_WHITESPACE|MSCF_JUSTIFY_LEFT);
  MovieControl = new TMovie(this,100,frameSize,movieSprite);
  OkButton = new TButton(this,IDOK);

}


TMainDlgClient::~TMainDlgClient ()
{
    Destroy();

    // INSERT>> Your destructor code here.
}


void TMainDlgClient::SetupWindow ()
{

  //
  // Determine size of client area
  //
  TDialog::SetupWindow();
  TRect borderRect(TPoint(0,0),TSize(6,6));
  MapDialogRect(*this,&borderRect);
  TSize borderGap = borderRect.Size();
  TSize clientSize(borderGap.cx*2,borderGap.cy*3);
  TRect movieRect = MovieControl->GetWindowRect();
  TSize buttonSize = OkButton->GetWindowRect().Size();
  clientSize.cy += buttonSize.cy;
  clientSize += movieRect.Size();

  //
  // Resize window to fit client, and
  // reposition child controls
  //
  TRect windowRect(TPoint(0,0),clientSize);
  long style = GetWindowLong(GWL_STYLE);
  long exStyle = GetWindowLong(GWL_EXSTYLE);
  AdjustWindowRectEx(windowRect,style,false,exStyle);
  OkButton->SetWindowPos(0,clientSize.cx-borderGap.cx-buttonSize.cx,
    clientSize.cy-borderGap.cy-buttonSize.cy,0,0,SWP_NOZORDER|SWP_NOSIZE|SWP_NOACTIVATE);
  MovieControl->SetWindowPos(0,borderGap.cx,borderGap.cy,0,0,SWP_NOZORDER|SWP_NOSIZE|SWP_NOACTIVATE);
  SetWindowPos(0,0,0,windowRect.Width(),windowRect.Height(),SWP_NOZORDER|SWP_NOMOVE|SWP_NOACTIVATE);

}

